Skip site navigation (1)Skip section navigation (2)

  
 
  

home | help
DBMAIL-IMAPD(8) 						 DBMAIL-IMAPD(8)

NAME
     dbmail-imapd  -  provides access to the DBMail system to clients supporting
     Internet Message Access Protocol, IMAP4r1, as specified in RFC 3501.

SYNOPSIS
     dbmail-imapd [--config configfile] [--pidfile pidfile]
     dbmail-imapd [--config configfile] [--pidfile pidfile] --no-daemon
     dbmail-imapd [--config configfile] [--pidfile pidfile] --inetd

DESCRIPTION
     The dbmail-imapd daemon is a fully featured IMAP4r1 server.

OPTIONS
     -p, --pidfile pidfile
	 Specify an alternate pid file. By default the daemons use  dbmail-<dae-
	 mon>.pid for their pid files, saving them in the directory specified by
	 the  pid_directory  entry  in dbmail.conf or if that does not exist the
	 value set by the configuration option --localstatedir, and will halt if
	 the pid file cannot be written. Use the -p pidfile option to place  the
	 pid file in your system's preferred location.

     -n, --no-daemon
	 No  daemonize:  inetd mode. The program remains attached to the console
	 from which it was started and will read and write on stdin/stdout. This
	 is useful for debugging when combined with the -v option.  It	is  also
	 used for running from (x)inetd.

     -D, --inetd
	 No daemonize: The program remains attached to the console and will lis-
	 ten  on the network sockets defined in dbmail.conf. This is mostly used
	 for xinetd (Extended Internet Service Daemon)

COMMON OPTIONS
     -f, --config configfile
	 Specify an alternate config file.

	 Use dbmail-<utility> --help to show the default location.

     -q, --quiet
	 Quietly skip interactive prompts  and	helpful  status  messages  which
	 would	otherwise  be  printed to stdout. Use two -q's to silence errors
	 which would otherwise be printed to stderr.

     -v, --verbose
	 Operate verbosely. Some of the utilities in the DBMail suite  can  take
	 two -v's for extra verbosity. Those which don't understand this conven-
	 tion  won't  complain about having the extra -v and will simply operate
	 at their normal verbosity.

     -V, --version
	 Show the version and copyright, then exit.

     -h, --help
	 Show a brief summary of options, then exit.

EXAMPLE
     For xinetd:

	 -----------------------------------------------------------
	 # /etc/xinet.d/dbmail-imap
	 #
	 service imap
	 {
		 socket_type	 = stream
		 wait		 = no
		 user		 = root
		 server 	 = /usr/local/sbin/dbmail-imapd
		 protocol	 = tcp
		 server_args	 = -n
		 log_on_failure  += USERID
		 disable	 = no
	 }
	 -----------------------------------------------------------

     For stunnel:

	 -----------------------------------------------------------
	 pid = /var/run/stunnel.pid
	 cert = /etc/stunnel/yourkeys.pem

	 # The next two sections will turn stunnel
	 # into a 'secure inetd'. This is mutually
	 # exclusive with the proxy sections below.
	 [dbmail-pop3d]
	 accept = 995
	 exec = /usr/local/sbin/dbmail-pop3d
	 execargs = dbmail-pop3d -n

	 [dbmail-imapd]
	 accept = 993
	 exec = /usr/local/sbin/dbmail-imapd
	 execargs = dbmail-imapd -n

	 # The next two sections will proxy
	 # from the secure protocol over to
	 # the insecure protocol. In this case,
	 # use BINDIP=localhost in dbmail.conf!
	 [pop3s]
	 accept  = 995
	 connect = 110

	 [imaps]
	 accept  = 993
	 connect = 143

	 # Useful if your preferred SMTP server doesn't do SSL/TLS.
	 # This is with your MTA configuration, not DBMail, per se.
	 [ssmtp]
	 accept  = 465
	 connect = 25
	 -----------------------------------------------------------

SEE ALSO
     dbmail(1),   dbmail.conf(5),   dbmail-deliver(1),	 dbmail-export(8),   db-
     mail-httpd(8),   dbmail-imapd(8),	 dbmail-lmtpd(8),  dbmail-pop3d(8),  db-
     mail-sieved(8), dbmail-sievecmd(8), dbmail-users(8), dbmail-util(8)

BUGS
     For the latest announcements, please subscribe to the DBMail announce mail-
     ing list[1]

     For general discussion, please subscribe  to  the	DBMail	general  mailing
     list[2]

     If  you experience an issue with DBMail, please report it on the DBMail Bug
     Tracker[3]. It may be helpful to have a debug log available.

LICENSE
     DBMail and its components are distributed under the terms of the  GNU  Gen-
     eral Public License Version 2. Copyrights are held variously by the authors
     listed below.

AUTHOR(S)
     DBMail is a collaborative effort among the core developers listed below and
     the  tremendous help of the testers, patchers and bug hunters listed in the
     AUTHORS and THANKS files found in the DBMail source distribution.

	 Alan Hicks	     Persistent Objects Ltd https://p-o.co.uk
	 Eelco van Beek      Aaron Stone	    Paul J Stevens
	 Roel Rozendaal      Open Source Engineer   NFG Net Facilities Group BV
	 Ilja Booij	     Palo Alto, CA USA	    http://www.nfg.nl
	 IC&S					    http://www.ic-s.nl

AUTHOR
     Alan Hicks <ahicks@p-o.co.uk>
	 Author.

NOTES
      1. DBMail announce mailing list
	 https://dbmail.org/wws/info/dbmail-announce/

      2. DBMail general mailing list
	 https://dbmail.org/wws/info/dbmail-general/

      3. DBMail Bug Tracker
	 https://github.com/dbmail/dbmail/issues

				   08/29/2026			 DBMAIL-IMAPD(8)

Want to link to this manual page? Use this URL:
<https://man.freebsd.org/cgi/man.cgi?query=dbmail-imapd&sektion=8&manpath=FreeBSD+Ports+15.1.quarterly>

home | help